﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"  xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="xml" encoding="utf-16"/>

  <!--Fonts-->
  <xsl:variable name="Font_12">  font-size:  12pt; font-family: Arial</xsl:variable>
  <xsl:variable name="Font_10">  font-size:  10pt; font-family: Arial</xsl:variable>
  <xsl:variable name="Font_8">  font-size:  8pt; font-family: Arial</xsl:variable>
  <xsl:variable name="Font_6">  font-size:  6pt; font-family: Arial</xsl:variable>
  <xsl:variable name="Font_Hidden">  font-size:  0pt; color: white; font-family: Arial</xsl:variable>

  <xsl:variable name="FontDefault">    font-size:  8pt; font-family: Arial</xsl:variable>
  <xsl:variable name="FontSmall">    font-size:  6pt; font-family: Arial</xsl:variable>
  <xsl:variable name="FontTiny">     font-size:  1pt; font-family: Arial</xsl:variable>
  <xsl:variable name="FontTitle">    font-size: 7pt; font-family: Arial</xsl:variable>
  <xsl:variable name="FontPage">	   font-size: 10pt; font-family: Arial</xsl:variable>
  
  <!--Printing options-->
  <xsl:variable name="ReportHeader">Header of report</xsl:variable>
  <xsl:variable name="PrintReportHeader">0</xsl:variable>
  <xsl:variable name="PrintCollectionOwner">0</xsl:variable>
  <xsl:variable name="PrintReportTitle">1</xsl:variable>
  <xsl:variable name="PrintBarcode">0</xsl:variable>
  <xsl:variable name="AddSpaceAtButtom">1</xsl:variable>

  <!--Page format-->
  <xsl:variable name="Einzug">20</xsl:variable>
  <xsl:variable name="Space">
    <xsl:text> </xsl:text>
  </xsl:variable>

  <xsl:template match="/Export_DiversityTaxonNames">
    <style type="text/css">
      body { margin-left:70px; }
    </style>
    <html>
      <head>
        <title>Export DiversityTaxonNames</title>
      </head>
      <body style="{$FontDefault}">
        <xsl:call-template name="Header"/>
        <br/>
        <br/>
        <xsl:call-template name="TaxonList"/>
      </body>
    </html>
  </xsl:template>

  <xsl:template name="Header">
    <xsl:value-of select="./Header/Date"/>
    <br/>
    Project: <xsl:value-of select="./Header/ProjectTitle"/>
  </xsl:template>

  <xsl:template name="Area">
    Area: 
    <xsl:for-each select="./Header/AreaList/Area">
      <xsl:if test="position > 1">,</xsl:if>
      <xsl:value-of select="PlaceNameCache"/>
    </xsl:for-each>
  </xsl:template>

  <xsl:template name="AnalysisCategoryValues">
    <table cellspacing="0" cellpadding="0" width="570" border="0" style="{$FontDefault}">
      <xsl:for-each select="./Header/AnalysisCategory">
        <tr>
          <td style="{$Font_10}" width="10" colspan ="3">
            <xsl:value-of select="DisplayText"/>
          </td>
        </tr>
        <xsl:for-each select="./AnalysisCategoryValueList/AnalysisCategoryValue">
          <tr>
            <td><xsl:value-of select="DisplayText"/>:</td>
            <td align="left"><xsl:value-of select="Description"/></td>
            <td></td>
          </tr> 
        </xsl:for-each>
      </xsl:for-each>
    </table>
  </xsl:template>

  <xsl:template name="TaxonList">
    <table cellspacing="0" cellpadding="0" width="800" border="0" style="{$FontDefault}">
      <tr height ="40">
        <th width="400" align="left">Taxon</th>
        <th width="120" align="left">Synonymy</th>
        <th width="300" align="left">NameURI</th>
      </tr>
      <xsl:for-each select="./TaxonList/Taxon">
        <xsl:call-template name="Taxon"/>
      </xsl:for-each>
    </table>
  </xsl:template>

  <xsl:template name="Taxon">
    <tr>
      <td style="{$Font_10}" align="left">
        <xsl:if test="SynType = 'accepted name'">
          <b>
            <xsl:value-of select="TaxonNameCache"/>
          </b>
        </xsl:if>
        <xsl:if test="SynType != 'accepted name'">
            <xsl:value-of select="TaxonNameCache"/>
        </xsl:if>
      </td>
      <td style="{$Font_10}" align="left">
        <xsl:value-of select="SynType"/>
      </td>
      <td style="{$Font_10}" align="left">
        <xsl:value-of select="../../Header/BaseURI"/><xsl:value-of select="NameID"/>
      </td>
    </tr>
  </xsl:template>

  <xsl:template name="Distribution">
    <xsl:if test="./DistributionList/Distribution != ''">
      <tr>
        <td>
          Distribution:
          <xsl:for-each select="./DistributionList/Distribution">
            <xsl:if test="position > 1">,</xsl:if>
            <xsl:value-of select="PlaceNameCache"/>
            <xsl:text> </xsl:text>
          </xsl:for-each>
        </td>
        <xsl:for-each select="./AnalysisList/Analysis">
          <td width="{$Einzug}"  align="center" style="{$Font_Hidden}">
            <xsl:text>x</xsl:text>
          </td>
        </xsl:for-each>
      </tr>
    </xsl:if>
  </xsl:template>

  <xsl:template name="Dist">
    <xsl:if test="./DistributionList/Distribution != ''">
      <span style="{$Font_8}"><br/>Dist.:
        <xsl:for-each select="./DistributionList/Distribution">
          <xsl:if test="position > 1">,</xsl:if>
          <xsl:value-of select="PlaceNameCache"/>
          <xsl:text> </xsl:text>
        </xsl:for-each>
      </span>
    </xsl:if>
  </xsl:template>

  <xsl:template name="Ref">
    <xsl:if test="./ReferenceList/Reference != ''">
      <span style="{$Font_8}">
        <br/>Ref.:
        <xsl:for-each select="./ReferenceList/Reference">
          <xsl:if test="position > 1">, </xsl:if>
          <xsl:value-of select="TaxonNameListRefText"/>
          <xsl:text> </xsl:text>
        </xsl:for-each>
      </span>
    </xsl:if>
  </xsl:template>

  <xsl:template name="Reference">
    <xsl:if test="./ReferenceList/Reference != ''">
      <tr>
        <td>
          Reference:
          <xsl:for-each select="./ReferenceList/Reference">
            <xsl:if test="position > 1">, </xsl:if>
            <xsl:value-of select="TaxonNameListRefText"/>
            <xsl:text> </xsl:text>
          </xsl:for-each>
        </td>
        <xsl:for-each select="./AnalysisList/Analysis">
          <td width="{$Einzug}"  align="center" style="{$Font_Hidden}">
            <xsl:text>x</xsl:text>
          </td>
        </xsl:for-each>
      </tr>
    </xsl:if>
  </xsl:template>



</xsl:stylesheet>